"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WatchWindowEventType = void 0;
exports.watchWindowState = watchWindowState;
exports.getSessionId = getSessionId;
exports.unwatchWindowState = unwatchWindowState;
exports.focusWindow = focusWindow;
exports.setParent = setParent;
exports.resetParent = resetParent;
exports.setMicMuteByTitle = setMicMuteByTitle;
exports.setWindowProtection = setWindowProtection;
exports.isSupported = isSupported;
const path_1 = require("path");
var WatchWindowEventType;
(function (WatchWindowEventType) {
    WatchWindowEventType[WatchWindowEventType["EVENT_ATTACH"] = 1] = "EVENT_ATTACH";
    WatchWindowEventType[WatchWindowEventType["EVENT_FOCUS"] = 2] = "EVENT_FOCUS";
    WatchWindowEventType[WatchWindowEventType["EVENT_BLUR"] = 3] = "EVENT_BLUR";
    WatchWindowEventType[WatchWindowEventType["EVENT_DETACH"] = 4] = "EVENT_DETACH";
    WatchWindowEventType[WatchWindowEventType["EVENT_FULLSCREEN"] = 5] = "EVENT_FULLSCREEN";
    WatchWindowEventType[WatchWindowEventType["EVENT_MOVERESIZE"] = 6] = "EVENT_MOVERESIZE";
})(WatchWindowEventType || (exports.WatchWindowEventType = WatchWindowEventType = {}));
/**
 * Устанавливает хук для отслеживания состояния окна
 * - Положение
 * - Фокус, блюр
 */
function watchWindowState(targetWindowNativeHandle, cb) {
    if (!isSupported()) {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    getAddon().watchWindowState(targetWindowNativeHandle, cb);
}
/**
 * Возвращает SessionID для текущего процесса (windows only)
 */
function getSessionId() {
    if (process.platform !== 'win32') {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    return getAddon().getSessionId();
}
/**
 * Отменяет хук, сделанный через watchWindowState
 */
function unwatchWindowState() {
    if (!isSupported()) {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    getAddon().unwatchWindowState();
}
/**
 * Переводит фокус на указанное окно
 */
function focusWindow(targetWindowNativeHandle) {
    if (!isSupported()) {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    getAddon().focusWindow(targetWindowNativeHandle);
}
function setParent(childWindowHandle, parentWindowHandle) {
    if (!isSupported()) {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    getAddon().setParent(childWindowHandle, parentWindowHandle);
}
function resetParent(windowHandle) {
    if (!isSupported()) {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    getAddon().resetParent(windowHandle);
}
function setMicMuteByTitle(title, mute) {
    if (!isSupported()) {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    return getAddon().setMicMuteByTitle(title, mute);
}
function setWindowProtection(windowHandle, enable) {
    if (!isSupported()) {
        throw new Error(`Not implemented on ${process.platform}`);
    }
    getAddon().setWindowProtection(windowHandle, enable);
}
function isSupported() {
    return process.platform === 'win32';
}
let addon;
function getAddon() {
    if (!isSupported()) {
        return undefined;
    }
    if (addon) {
        return addon;
    }
    addon = require('node-gyp-build')((0, path_1.join)(__dirname, '..'));
    return addon;
}
//# sourceMappingURL=index.js.map